from testtools import TestCase
import hooks
from mock import patch
import shutil
import tempfile
import os


class ConfigChangedTest(TestCase):
    def setUp(self):
        super(ConfigChangedTest, self).setUp()
        self.dirname = tempfile.mkdtemp()

    def tearDown(self):
        super(ConfigChangedTest, self).tearDown()
        if os.path.exists(self.dirname):
            shutil.rmtree(self.dirname)

    @patch('hooks.subprocess.call')
    @patch('hooks.close_port')
    @patch('hooks.open_port')
    @patch('hooks.conf_disable')
    @patch('hooks.ensure_extra_packages')
    @patch('hooks.ensure_package_status')
    @patch('hooks.ship_logrotate_conf')
    @patch('hooks.update_nrpe_checks')
    @patch('hooks.run')
    @patch('hooks.create_security')
    @patch('hooks.create_mpm_workerfile')
    @patch('hooks.log')
    @patch('hooks.relation_ids')
    @patch('hooks.relations_of_type')
    @patch('hooks.config_get')
    @patch('hooks.get_reverseproxy_data')
    @patch('hooks.service_apache2')
    @patch('hooks.relation_set')
    def test_config_changed_ensure_empty_site_dir(
            self, mock_relation_set, mock_service_apache2,
            mock_reverseproxy, mock_config_get,
            mock_relations_of_type, mock_relation_ids, mock_log,
            mock_create_mpm_workerfile, mock_create_security, mock_run,
            mock_update_nrpe_checks, mock_ship_logrotate_conf,
            mock_ensure_package_status, mock_ensure_extra_packages,
            mock_conf_disable, mock_open_port, mock_close_port, mock_call):
        """config-changed hook: Site directories should be empty."""
        mock_config_get.return_value = {
            "ssl_cert": "",
            "ssl_key": "",
            "package_status": "",
            "enable_modules": "",
            "disable_modules": "",
            "mpm_type": "",
            "ssl_certlocation": "",
            "ssl_keylocation": "",
            "ssl_chainlocation": "",
            "use_rsyslog": "",
            "config_change_command": "",
            "openid_provider": "",
            "servername": "foobar",
            "vhost_http_template": "",
            "vhost_https_template": "",
        }
        hooks.default_apache_base_dir = self.dirname
        hooks.default_apache22_config_dir = "%s/conf.d" % self.dirname
        hooks.default_apache24_config_dir = "%s/conf-available" % self.dirname
        os.mkdir("%s/sites-enabled" % self.dirname)
        os.mkdir("%s/sites-available" % self.dirname)
        os.mkdir("%s/conf.d" % self.dirname)
        hooks.config_changed()
        self.assertEqual(
            len(os.listdir("%s/%s" % (self.dirname, "sites-enabled"))), 0)
        self.assertEqual(
            len(os.listdir("%s/%s" % (self.dirname, "sites-available"))), 0)
